@@ -32,6 +32,13 @@
 #include "errors.h"
 #include "natstrcmp.h"
 
+// random number
+u_int32_t irand( u_int32_t b, u_int32_t e)
+{
+    double r = e - b + 1;
+    return b + (u_int32_t)(r * rand()/(RAND_MAX+1.0));
+}
+
 // List functions
 
 struct sDirEntryList * newDirEntryList(void) {
@@ -104,6 +111,7 @@ struct sLongDirEntryList *
 		return NULL;
 	}
 	memcpy(new->lde, lde, DIR_ENTRY_SIZE);
+	new->next=NULL;
 
 	if (list != NULL) {
 		tmp=list;
@@ -206,10 +214,15 @@ void insertDirEntryList(struct sDirEntryList *new, struct sDirEntryList *list) {
 	struct sDirEntryList *tmp, *dummy;
 
 	tmp=list;
-	while ((tmp->next != NULL) &&
-	       (cmpEntries(new, tmp->next) >= 0)) {
-		tmp=tmp->next;
+	
+	// comparison is unnecessary for randomization and listing
+	if (!OPT_LIST && !OPT_RANDOM) {
+		while ((tmp->next != NULL) &&
+		(cmpEntries(new, tmp->next) >= 0)) {
+			tmp=tmp->next;
+		}
 	}
+	
 	dummy=tmp->next;
 	tmp->next=new;
 	new->next=dummy;
@@ -229,3 +242,34 @@ void freeDirEntryList(struct sDirEntryList *list) {
 		free (tmp);
 	}
 }
+
+void randomizeDirEntryList(struct sDirEntryList *list, u_int32_t entries) {
+/*
+	randomize entry list
+*/
+	assert(list != NULL);
+
+	struct sDirEntryList *randlist, *tmp, *dummy1, *dummy2;
+	u_int32_t i, j, pos;
+	
+	randlist=list;
+	for (i=0; i < entries; i++) {
+		pos=irand(0, entries - 1 - i);
+		
+		tmp=randlist;
+		// after the loop tmp->next is the selected item
+		for (j=0; j<pos; j++) {
+			tmp=tmp->next;
+		}
+		
+		// put selected entry to top of list
+		dummy1=tmp->next;
+		tmp->next=dummy1->next;
+
+		dummy2=randlist->next;
+		randlist->next=dummy1;
+		dummy1->next=dummy2;
+		
+		randlist=randlist->next;
+	}
+}
