@@ -30,6 +30,7 @@
 #include <assert.h>
 #include <errno.h>
 #include <locale.h>
+#include <time.h>
 
 // project includes
 #include "endianness.h"
@@ -47,7 +48,7 @@
 
 // program information
 #define INFO_PROGRAM "FATSort Utility"
-#define INFO_VERSION "0.9.12"
+#define INFO_VERSION "0.9.14"
 #define INFO_AUTHOR "Boris Leidner <fatsort(at)formenos.de>"
 #define INFO_HEADER INFO_PROGRAM " " INFO_VERSION " by " INFO_AUTHOR
 #define INFO_LICENSE	"License GPLv2: GNU GPL version 2 (see LICENSE.txt)\n" \
@@ -71,6 +72,7 @@
 			"\t-D dir\t Sort directory dir and all subdirectories\n" \
 			"\t-q\t Be quiet\n" \
 			"\t-r\t Sort in reverse order\n" \
+			"\t-R\t Sort in random order\n" \
 			"\t-v\t Print version information\n" \
 			"\n" \
 			"Device must be a FAT16 or FAT32 file system. FAT12 is not supported yet.\n" \
@@ -170,6 +172,9 @@ int main(int argc, char *argv[]) {
 	parse arguments and options and start sorting
 */
 
+	// initialize rng
+	srand(time(0));
+
 	// use locale from environment
 	if (setlocale(LC_ALL, "") == NULL) {
 		myerror("Could not set locale!");
