@@ -27,7 +27,7 @@
 #include "errors.h"
 #include "FAT_fs.h"
 
-u_int32_t OPT_VERSION, OPT_HELP, OPT_INFO, OPT_QUIET, OPT_IGNORE_CASE, OPT_ORDER, OPT_LIST, OPT_REVERSE, OPT_FORCE, OPT_NATURAL_SORT, OPT_RECURSIVE;
+u_int32_t OPT_VERSION, OPT_HELP, OPT_INFO, OPT_QUIET, OPT_IGNORE_CASE, OPT_ORDER, OPT_LIST, OPT_REVERSE, OPT_FORCE, OPT_NATURAL_SORT, OPT_RECURSIVE, OPT_RANDOM;
 char OPT_DIRECTORY[MAX_PATH_LEN+1];
 
 int32_t parse_options(int argc, char *argv[]) {
@@ -42,9 +42,12 @@ int32_t parse_options(int argc, char *argv[]) {
 
 	// natural sort
 	OPT_NATURAL_SORT = 0;
+	
+	// random sort order
+	OPT_RANDOM = 0;
 
 	opterr=0;
-	while ((c=getopt(argc, argv, "ivhqcfo:lrnd:D:")) != -1) {
+	while ((c=getopt(argc, argv, "ivhqcfo:lrRnd:D:")) != -1) {
 		switch(c) {
 			case 'c' : OPT_IGNORE_CASE = 1; break;
 			case 'f' : OPT_FORCE = 1; break;
@@ -74,6 +77,7 @@ int32_t parse_options(int argc, char *argv[]) {
 			case 'n' : OPT_NATURAL_SORT = 1; break;
 			case 'q' : OPT_QUIET = 1; break;
 			case 'r' : OPT_REVERSE = -1; break;
+			case 'R' : OPT_RANDOM = 1; break;
 			case 'v' : OPT_VERSION = 1; break;
 			default :
 				myerror("Unknown option '%c'.", optopt);
