@@ -156,7 +156,7 @@ void parseLongFilenamePart(struct sLongDirEntry *lde, char *str) {
 	incount=26;
 	outcount=MAX_PATH_LEN;
 
-        cd = iconv_open("UTF-8", "UTF-16");
+        cd = iconv_open("UTF-8", "UTF-16LE");
 
         if (cd == (iconv_t)-1) {
                 myerror("iconv_open failed!");
@@ -198,7 +198,7 @@ void parseShortFilename(struct sShortDirEntry *sde, char *str) {
 	}
 }
 
-int32_t parseClusterChain(FILE *fd, struct sBootSector *bs, struct sClusterChain *chain, struct sDirEntryList *list) {
+int32_t parseClusterChain(FILE *fd, struct sBootSector *bs, struct sClusterChain *chain, struct sDirEntryList *list, u_int32_t *direntries) {
 /*
 	parses a cluster chain and puts found directory entries to list
 */
@@ -207,6 +207,7 @@ int32_t parseClusterChain(FILE *fd, struct sBootSector *bs, struct sClusterChain
 	assert(bs != NULL);
 	assert(chain != NULL);
 	assert(list != NULL);
+	assert(direntries != NULL);
 
 	int32_t j, ret;
 	u_int32_t maxEntries, entries=0;
@@ -215,6 +216,8 @@ int32_t parseClusterChain(FILE *fd, struct sBootSector *bs, struct sClusterChain
 	struct sLongDirEntryList *llist;
 	char tmp[MAX_PATH_LEN+1], dummy[MAX_PATH_LEN+1], sname[MAX_PATH_LEN+1], lname[MAX_PATH_LEN+1];
 
+	*direntries=0;
+	
 	maxEntries = bs->BS_SecPerClus * SwapInt16(bs->BS_BytesPerSec) / DIR_ENTRY_SIZE;
 
 	chain=chain->next;	// head element
@@ -264,6 +267,7 @@ int32_t parseClusterChain(FILE *fd, struct sBootSector *bs, struct sClusterChain
 				}
 
 				insertDirEntryList(lnde, list);
+				(*direntries)++;
 				entries=0;
 				llist = NULL;
 				lname[0]='\0';
@@ -632,7 +636,7 @@ int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, ch
 	assert(bs != NULL);
 	assert(path != NULL);
 
-	u_int32_t clen, value, c;
+	u_int32_t clen, value, c, direntries;
 	struct sClusterChain *ClusterChain=newClusterChain();
 	char newpath[MAX_PATH_LEN+1]={0};
 
@@ -654,10 +658,12 @@ int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, ch
 	if (!OPT_LIST) {
 		// DEBUG
 // 		printf("%s %s\n", OPT_DIRECTORY, path);
-		if (parseClusterChain(fd, bs, ClusterChain, list) == -1) {
+		if (parseClusterChain(fd, bs, ClusterChain, list, &direntries) == -1) {
 			myerror("Failed to parse cluster chain!");
 			return -1;
 		}
+		
+		if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
 
 		if ((strlen(OPT_DIRECTORY) == 0) ||
 		    (strncmp(OPT_DIRECTORY, path, strlen(OPT_DIRECTORY)) == 0)) {
@@ -674,10 +680,11 @@ int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, ch
 		}
 	} else {
 		printf("%s\n", path);
-		if (parseClusterChain(fd, bs, ClusterChain, list) == -1) {
+		if (parseClusterChain(fd, bs, ClusterChain, list, &direntries) == -1) {
 			myerror("Failed to parse cluster chain!");
 			return -1;
 		}
+		
 		printf("\n");
 	}
 
@@ -734,6 +741,7 @@ int32_t sort_FAT16_rootdir(FILE *fd, struct sBootSector *bs) {
 	off_t BSOffset;
 	u_int32_t FATSz, i, ret;
 	u_int32_t entries,count=0, c, value;
+	u_int32_t direntries=0;
 	char newpath[MAX_PATH_LEN+1]={0};
 
 	struct sDirEntryList *list = newDirEntryList();
@@ -763,11 +771,14 @@ int32_t sort_FAT16_rootdir(FILE *fd, struct sBootSector *bs) {
 			myerror("Failed to parse directory entries!");
 			return -1;
 		}
+		direntries++;
 		// well, one entry read, but not matched
 		if (entries == 0) count++;
 	}
 
 	if (!OPT_LIST) {
+		if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
+		
 		if ((strlen(OPT_DIRECTORY) == 0) ||
 		    (strncmp(OPT_DIRECTORY, "/", strlen(OPT_DIRECTORY)) == 0)) {
 			infomsg("Sorting directory /\n");
